@@ -9,6 +9,7 @@ from .riff_parser import parse_chunk, ChunkDescriptor, ListChunkDescriptor
 from .wave_ixml_reader import WavIXMLFormat
 from .wave_bext_reader import WavBextReader
 from .wave_info_reader import WavInfoChunkReader
+from .wave_adm_reader import WavADMReader
 
 #: Calculated statistics about the audio data.
 WavDataDescriptor = namedtuple('WavDataDescriptor', 'byte_count frame_count')
@@ -39,6 +40,8 @@ class WavInfoReader:
             The text encoding to use when decoding the string
             fields of the Broadcast-WAV extension. Per EBU 3285 this is ASCII
             but this parameter is available to you if you encounter a weirdo.
+
+
         """
         
         self.info_encoding = info_encoding
@@ -75,6 +78,9 @@ class WavInfoReader:
         #: :class:`wavinfo.wave_ixml_reader.WavIXMLFormat` with iXML metadata
         self.ixml = self._get_ixml(wavfile)
 
+        #: :class:`wavinfo.wave_axml_reader.WavAxmlReader` with ADM metadata
+        self.adm  = self._get_adm(wavfile)
+
         #: :class:`wavinfo.wave_info_reader.WavInfoChunkReader` with RIFF INFO metadata
         self.info = self._get_info(wavfile, encoding=self.info_encoding)
         self.data = self._describe_data()
@@ -85,7 +91,7 @@ class WavInfoReader:
         return chunk_descriptor.read_data(from_stream) if chunk_descriptor else None
 
     def _describe_data(self):
-        data_chunk = next(c for c in self.main_list if c.ident == b'data')
+        data_chunk = next(c for c in self.main_list if type(c) is ChunkDescriptor and c.ident == b'data')
 
         return WavDataDescriptor(byte_count=data_chunk.length,
                                  frame_count=int(data_chunk.length / self.fmt.block_align))
@@ -130,6 +136,11 @@ class WavInfoReader:
         bext_data = self._find_chunk_data(b'bext', f, default_none=True)
         return WavBextReader(bext_data, encoding) if bext_data else None
 
+    def _get_adm(self, f):
+        axml = self._find_chunk_data(b'axml', f, default_none=True)
+        chna = self._find_chunk_data(b'chna', f, default_none=True)
+        return WavADMReader(axml_data=axml, chna_data=chna) if axml and chna else None
+
     def _get_ixml(self, f):
         ixml_data = self._find_chunk_data(b'iXML', f, default_none=True)
         return None if ixml_data is None else WavIXMLFormat(ixml_data.rstrip(b'\0'))
@@ -140,24 +151,23 @@ class WavInfoReader:
 
         :yields: a string, the :scope: of the metadatum, the string :name: of the
         metadata field, and the value.
+
+        
         """
 
-        scopes = ('fmt', 'data')  # 'bext', 'ixml', 'info')
+        scopes = ('fmt', 'data', 'ixml', 'bext', 'info', 'adm')
 
         for scope in scopes:
-            attr = self.__getattribute__(scope)
-            for field in attr._fields:
-                yield scope, field, attr.__getattribute__(field)
+            if scope in ['fmt', 'data']:
+                attr = self.__getattribute__(scope)
+                for field in attr._fields:
+                    yield scope, field, attr.__getattribute__(field)
 
-            if self.bext is not None:
-                bext_dict = (self.bext or {}).to_dict()
-                for key in bext_dict.keys():
-                    yield 'bext', key, bext_dict[key]
-
-            if self.info is not None:
-                info_dict = self.info.to_dict()
-                for key in info_dict.keys():
-                    yield 'info', key, info_dict[key]
+            else:
+                dict = self.__getattribute__(scope).to_dict() if self.__getattribute__(scope) else {}
+                for key in dict.keys():
+                    yield scope, key, dict[key]
+        
 
     def __repr__(self):
         return 'WavInfoReader({}, {}, {})'.format(self.path, self.info_encoding, self.bext_encoding)
